
<p align="center">
    <img src="https://i.postimg.cc/s2P93CGN/blue-logo-no-text-svg.png" alt="Rumorz Logo" width="150"/>
</p>

# 🚀 What is Rumorz?

Rumorz tracks 100s of sources across the web and financial markets to extract investments insights and sentiment analytics.
We index a large amount of web data in real-time and use AI Agents to 
save you time reading, staying up to date, and identifying trends and investment
opportunities.


## How does it work?

AI Agents read and analyze web data 24/7 and ingest 100s of pages of text a day into a knowledge graph, allowing
social and semantic analysis at state of the art performance.

<p align="center">
    <img src="https://github.com/rumorz-ai/rumorz/blob/main/docs/assets/architecture.png" alt="Rumorz architecture" width='500'>
</p>


## 🛠️ Install

```bash
pip install rumorz
```

## 🚀  Vision
Rumorz provides investors and traders their own AI agent, aligned with their goals and preferences and with 24/7 access to real-time, institutional grade financial data and analytics.


## 🧠 How does it work?
**The Graph**

Our AI Agents ingest 100s of pages of text a day into a knowledge graph (the Graph), allowing fast semantic retrieval of market data and text data from news, research, social media. The Graph indexes data on 1200 crypto tokens in real-time, making it available to agents for research or decision making.

This is ideal for AI use cases, and has been built from scratch without the constraints of legacy tables or complicated joins.

**Agents**

Agents are autonomous and run research and analysis for you 24/7. You don’t need to prompt them or think of questions to ask. You can simply give them a goal, and they will go from there. They will start doing research and analysis and come up with a strategy to achieve your goal.


## 🔒 API Access

Email othmane@rumorz.io with "Rumorz API KEY" in the subject line.

## ✅ Features
- **Screener**: a ranking of all entities in the Rumorz Graph by social metrics (mentions, sentiment, excitement, optimism, pessimism, fear, uncertainty, surprise')
- **Real-time updates**: Get real-time updates on the cryptomarket or specific entities
- **Tick-level time-series data**: get real-time amd historical sentiment data for all entities in the Graph
- **Annotated news**: Get news articles related to any entity with sentiment and AI annotations
- **Search**: search and find financial assets, companies or people in the Rumorz Graph
- **Copilot**: An Agent with knowledge of the Rumorz Python package that can generate custom scripts for you

## 📚 Use cases

- AI Agents
- Market monitoring and alerts
- Sentiment based investment and trading strategies
- Financial research, analysis and alpha generation
- Data source for AI Agents and RAG based applications
- Social media bot development: Telegram, Discord, Twitter/X etc.
- Workflow automation: emails, PDFs, reports etc.

# 🚀 Examples
* [Using the SDK Copilot to generate docs.rumorz.io](docs/examples/copilot.py)
* [Various examples](docs/examples/examples.py)
* [Plot the sentiment scores of Bitcoin over time](docs/examples/bitcoin_sentiment.py)
